==> kubernetes-model-1.0.56-sources.jar: io/fabric8/openshift/api/model/ClusterRoleFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.String;
import javax.validation.constraints.NotNull;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import javax.validation.Valid;
import io.fabric8.kubernetes.api.model.validators.CheckObjectMeta;
import java.util.List;
import java.lang.Object;
import java.util.Map;
import com.fasterxml.jackson.annotation.JsonIgnore;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;

public interface ClusterRoleFluent<A extends ClusterRoleFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public String getKind();
    public A withKind(String kind);
    public ObjectMeta getMetadata();
    public A withMetadata(ObjectMeta metadata);
    public ClusterRoleFluent.MetadataNested<A> withNewMetadata();
    public ClusterRoleFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public ClusterRoleFluent.MetadataNested<A> editMetadata();
    public A addToRules(PolicyRule... items);
    public A removeFromRules(PolicyRule... items);
    public List<PolicyRule> getRules();
    public A withRules(List<PolicyRule> rules);
    public A withRules(PolicyRule... rules);
    public ClusterRoleFluent.RulesNested<A> addNewRule();
    public ClusterRoleFluent.RulesNested<A> addNewRuleLike(PolicyRule item);

    public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<ClusterRoleFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface RulesNested<N> extends Nested<N>,PolicyRuleFluent<ClusterRoleFluent.RulesNested<N>>{

        
    public N and();    public N endRule();
}


}

==> kubernetes-model-1.0.64-sources.jar: io/fabric8/openshift/api/model/ClusterRoleFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.validators.CheckObjectMeta;
import java.lang.String;
import javax.validation.constraints.NotNull;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import io.sundr.builder.annotations.Buildable;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import javax.annotation.Generated;
import io.fabric8.kubernetes.api.builder.Fluent;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import javax.validation.Valid;
import java.lang.Object;
import lombok.ToString;
import java.util.Map;

public interface ClusterRoleFluent<A extends ClusterRoleFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public String getKind();
    public A withKind(String kind);
    public ObjectMeta getMetadata();
    public A withMetadata(ObjectMeta metadata);
    public ClusterRoleFluent.MetadataNested<A> withNewMetadata();
    public ClusterRoleFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public ClusterRoleFluent.MetadataNested<A> editMetadata();
    public ClusterRoleFluent.MetadataNested<A> editOrNewMetadata();
    public ClusterRoleFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    public A addToRules(PolicyRule... items);
    public A removeFromRules(PolicyRule... items);
    public List<PolicyRule> getRules();
    public A withRules(List<PolicyRule> rules);
    public A withRules(PolicyRule... rules);
    public ClusterRoleFluent.RulesNested<A> addNewRule();
    public ClusterRoleFluent.RulesNested<A> addNewRuleLike(PolicyRule item);

    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<ClusterRoleFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface RulesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PolicyRuleFluent<ClusterRoleFluent.RulesNested<N>>{

        
    public N and();    public N endRule();
}


}
